@@ -31,7 +31,12 @@
 #ifndef MIDIDEVICE_H
 #define MIDIDEVICE_H
 
+/* Microsoft compiler can't deal with the real name - are we surprised? */
+#ifndef _MSC_VER
 #include <strstream.h>
+#else
+#include <strstrea.h>
+#endif
 
 #include "Song.h"
 
