@@ -17,8 +17,12 @@ struct unixware_midi_softc midi_sc[MIDI_UNITS];
  * 	0	Fully MPU401 compat.
  *	1	MPU401 only in UART mode
  *	2	Music Quest MQX32 with SMPTE
- *	3	Gravis UltraSound
- *	4	SoundBlaster
+ *	3	Gravis w/ internal voices - GF1 (GUS)
+ *	4	Gravis w/ internal voices - Iwave (PnP)
+ *	5	Gravis w/ external voices - GF1 (GUS)
+ *	6	Gravis w/ external voices - Iwave (PnP)
+ *	7	SoundBlaster
+ *	8	A PC style UART (16450, etc.)
  *
  * XXX
  * Ideally this information should be in the System file somewhere,
@@ -56,4 +60,3 @@ MIDI_0_VECT
 , MIDI_3_VECT
 #endif
 };
-
