@@ -4,7 +4,7 @@
 #include "Event.h"
 
 extern Event *ReadEventFromSMFTrack(SMFTrack &track, unsigned long &last_t,
-    const char *&errstr);
+    int use_time, const char *&errstr);
 extern int WriteEventToSMFTrack(SMFTrack &track, unsigned long &last_t,
-    const Event *event, const char *&errstr);
+    const Event *event, int use_time, const char *&errstr);
 #endif
