@@ -37,7 +37,7 @@ class MetaPortNumberEvent : public MetaEvent {
 	friend ostream &operator<<(ostream &os, const MetaPortNumberEvent &e);
 public:
 	MetaPortNumberEvent();
-	MetaPortNumberEvent(unsigned long t, unsigned char p);
+	MetaPortNumberEvent(unsigned long t, int p);
 	MetaPortNumberEvent(const MetaPortNumberEvent &e);
 	virtual ~MetaPortNumberEvent();
 	virtual Event *Dup(void) const
@@ -47,17 +47,32 @@ public:
 	virtual char *GetTypeStr(void) const
 	    {return ("MetaPortNumberEvent");}
 	virtual char *GetEventStr(void) const;
-	unsigned char GetPort(void) const {return (port);}
+	int GetPort(void) const {
+		if (GetWildcard(wc_port))
+			return (WC_PORT);
+		else
+			return (port);
+	}
 
-	void SetPort(unsigned char p) {port = p;}
+	void SetPort(int p) {
+		if (p == WC_PORT)
+			SetWildcard(wc_port);
+		else {
+			port = p;
+			ClearWildcard(wc_port);
+		}
+	}
 
 	MetaPortNumberEvent &operator=(const MetaPortNumberEvent &e);
 
 	virtual const char *SMFRead(SMFTrack &t);
 	virtual const char *SMFWrite(SMFTrack &t) const;
+
+	static const int WC_PORT;
 protected:
 	virtual int Equal(const Event *e) const;
 private:
+	static const unsigned long wc_port;
 	unsigned char port;
 };
 #endif
