@@ -37,16 +37,28 @@ class NormalEvent : public Event {
 	friend ostream &operator<<(ostream &os, const NormalEvent &e);
 public:
 	NormalEvent();
-	NormalEvent(unsigned long t, unsigned char chan);
+	NormalEvent(unsigned long t, int chan);
 	NormalEvent(const NormalEvent &e);
 	virtual Event *Dup(void) const {return (new NormalEvent(*this));}
 
 	virtual EventType GetType(void) const {return (NORMAL);}
 	virtual char *GetTypeStr(void) const {return ("NormalEvent");}
 	virtual char *GetEventStr(void) const;
-	unsigned char GetChannel(void) const {return (channel);}
+	int GetChannel(void) const {
+		if (GetWildcard(wc_channel))
+			return (WC_CHANNEL);
+		else
+			return (channel);
+	}
 
-	void SetChannel(unsigned char chan) {channel = chan;}
+	void SetChannel(int chan) {
+		if (chan == WC_CHANNEL)
+			SetWildcard(wc_channel);
+		else {
+			channel = chan;
+			ClearWildcard(wc_channel);
+		}
+	}
 
 	NormalEvent &operator=(const NormalEvent &e);
 
@@ -62,9 +74,12 @@ public:
 		dummy = &t;
 		return (0);
 	}
+
+	static const int WC_CHANNEL;
 protected:
 	virtual int Equal(const Event *e) const;
 private:
+	static const unsigned long wc_channel;
 	unsigned char channel;
 };
 #endif
