@@ -37,25 +37,39 @@ class PitchWheelEvent : public NormalEvent {
 	friend ostream &operator<<(ostream &os, const PitchWheelEvent &e);
 public:
 	PitchWheelEvent();
-	PitchWheelEvent(unsigned long t, unsigned char chan,
-	    short val);
+	PitchWheelEvent(unsigned long t, int chan, long val);
 	PitchWheelEvent(const PitchWheelEvent &e);
 	virtual Event *Dup(void) const {return (new PitchWheelEvent(*this));}
 
 	virtual EventType GetType(void) const {return (PITCHWHEEL);}
 	virtual char *GetTypeStr(void) const {return ("PitchWheelEvent");}
 	virtual char *GetEventStr(void) const;
-	short GetValue(void) const {return (value);}
+	long GetValue(void) const {
+		if (GetWildcard(wc_value))
+			return (WC_VALUE);
+		else
+			return (value);
+	}
 
-	void SetValue(short val) {value = val;}
+	void SetValue(long val) {
+		if (val == WC_VALUE)
+			SetWildcard(wc_value);
+		else {
+			value = val;
+			ClearWildcard(wc_value);
+		}
+	}
 
 	PitchWheelEvent &operator=(const PitchWheelEvent &e);
 
 	virtual const char *SMFRead(SMFTrack &t);
 	virtual const char *SMFWrite(SMFTrack &t) const;
+
+	static const long WC_VALUE;
 protected:
 	virtual int Equal(const Event *e) const;
 private:
+	static const unsigned long wc_value;
 	short value;
 };
 #endif
