@@ -48,8 +48,18 @@ public:
 	virtual EventType GetType(void) const {return (SYSTEMEXCLUSIVE);}
 	virtual char *GetTypeStr(void) const {return ("SystemExclusiveEvent");}
 	virtual char *GetEventStr(void) const;
-	const unsigned char *GetData(void) const {return (data);}
-	long GetLength(void) const {return (length);}
+	const unsigned char *GetData(void) const {
+		if (GetWildcard(wc_data))
+			return (WC_DATA);
+		else
+			return (data);
+	}
+	long GetLength(void) const {
+		if (GetWildcard(wc_data))
+			return (WC_LENGTH);
+		else
+			return (length);
+	}
 	unsigned char GetContinued(void) const {return (continued);}
 
 	void SetData(const unsigned char *data, long length);
@@ -59,9 +69,13 @@ public:
 
 	virtual const char *SMFRead(SMFTrack &t);
 	virtual const char *SMFWrite(SMFTrack &t) const;
+
+	static const unsigned char *WC_DATA;
+	static const long WC_LENGTH;
 protected:
 	virtual int Equal(const Event *e) const;
 private:
+	static const unsigned long wc_data;
 	long length;
 	unsigned char continued;
 	unsigned char *data;
