@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1993, 1994, 1995 Michael B. Durian.  All rights reserved.
+ * Copyright (c) 1993, 1994, 1995, 1996 Michael B. Durian.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,6 +31,9 @@
 #ifndef SMFHEAD_H
 #define SMFHEAD_H
 
+extern "C" {
+#include <tcl.h>
+}
 #include <iostream.h>
 
 class SMFHead {
@@ -50,6 +53,8 @@ public:
 
 	int Read(int fd);
 	int Write(int fd) const;
+	int Read(Tcl_Channel channel);
+	int Write(Tcl_Channel channel) const;
 
 	SMFHead &operator=(const SMFHead &h);
 private:
