@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 1993, 1994, 1995 Michael B. Durian.  All rights reserved.
+ * Copyright (c) 1993, 1994, 1995, 1996 Michael B. Durian.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -31,133 +31,125 @@
 #ifndef SMFUTILS_H
 #define SMFUTILS_H
 
+extern "C" {
+#include <tcl.h>
+}
+
 /*
  * convert midi order to host order and vice-versa
  * Trying a new inline function version.  This generates silly warnings,
  * but I believe it is clearer and faster.
  */
-#if defined(i386) || defined(vax) || defined(osf1)
+#if WORDS_BIGENDIAN
+
 inline long
 mtohl(long l)
 {
-	union {
-		long l;
-		char c[4];
-	} swap;
-	char tmp_c;
 
-	swap.l = l;
-	tmp_c = swap.c[0];
-	swap.c[0] = swap.c[3];
-	swap.c[3] = tmp_c;
-	tmp_c = swap.c[1];
-	swap.c[1] = swap.c[2];
-	swap.c[2] = tmp_c;
-	return (swap.l);
+	return (l);
 }
 
 inline long
 htoml(long l)
 {
 
-	union {
-		long l;
-		char c[4];
-	} swap;
-	char tmp_c;
-
-	swap.l = l;
-	tmp_c = swap.c[0];
-	swap.c[0] = swap.c[3];
-	swap.c[3] = tmp_c;
-	tmp_c = swap.c[1];
-	swap.c[1] = swap.c[2];
-	swap.c[2] = tmp_c;
-	return (swap.l);
+	return (l);
 }
 
 inline short
 mtohs(short s)
 {
-	union {
-		short s;
-		char c[2];
-	} swap;
-	char tmp_c;
 
-	swap.s = s;
-	tmp_c = swap.c[0];
-	swap.c[0] = swap.c[1];
-	swap.c[1] = tmp_c;
-	return (swap.s);
+	return (s);
 }
 
 inline short
 htoms(short s)
 {
 
-	union {
-		short s;
-		char c[2];
-	} swap;
-	char tmp_c;
-
-	swap.s = s;
-	tmp_c = swap.c[0];
-	swap.c[0] = swap.c[1];
-	swap.c[1] = tmp_c;
-	return (swap.s);
+	return (s);
 }
-#if 0
-#define mtohl(l) ((((l) << 24) & 0xff000000L) | (((l) << 8) & 0x00ff0000L) \
-    | (((l) >> 8) & 0x0000ff00L) | (((l) >> 24) & 0x000000ffL))
-#define htoml(l) ((((l) << 24) & 0xff000000L) | (((l) << 8) & 0x00ff0000L) \
-    | (((l) >> 8) & 0x0000ff00L) | (((l) >> 24) & 0x000000ffL))
-#define mtohs(s) ((((s) << 8) & 0xff00) | (((s) >> 8) & 0x00ff))
-#define htoms(s) ((((s) << 8) & 0xff00) | (((s) >> 8) & 0x00ff))
-#endif
+
 #else
 
 inline long
 mtohl(long l)
 {
+	union {
+		long l;
+		char c[4];
+	} swap;
+	char tmp_c;
 
-	return (l);
+	swap.l = l;
+	tmp_c = swap.c[0];
+	swap.c[0] = swap.c[3];
+	swap.c[3] = tmp_c;
+	tmp_c = swap.c[1];
+	swap.c[1] = swap.c[2];
+	swap.c[2] = tmp_c;
+	return (swap.l);
 }
 
 inline long
 htoml(long l)
 {
 
-	return (l);
+	union {
+		long l;
+		char c[4];
+	} swap;
+	char tmp_c;
+
+	swap.l = l;
+	tmp_c = swap.c[0];
+	swap.c[0] = swap.c[3];
+	swap.c[3] = tmp_c;
+	tmp_c = swap.c[1];
+	swap.c[1] = swap.c[2];
+	swap.c[2] = tmp_c;
+	return (swap.l);
 }
 
 inline short
 mtohs(short s)
 {
+	union {
+		short s;
+		char c[2];
+	} swap;
+	char tmp_c;
 
-	return (s);
+	swap.s = s;
+	tmp_c = swap.c[0];
+	swap.c[0] = swap.c[1];
+	swap.c[1] = tmp_c;
+	return (swap.s);
 }
 
 inline short
 htoms(short s)
 {
 
-	return (s);
+	union {
+		short s;
+		char c[2];
+	} swap;
+	char tmp_c;
+
+	swap.s = s;
+	tmp_c = swap.c[0];
+	swap.c[0] = swap.c[1];
+	swap.c[1] = tmp_c;
+	return (swap.s);
 }
-#if 0
-#define mtohl(l) l
-#define mtohs(s) s
-#define htoml(l) l
-#define htoms(s) s
-#endif
 #endif
 
 
 extern long MRead(int fd, char *data, long len);
 extern long MWrite(int fd, char *data, long len);
-extern int MEof(void);
-extern void ClearMEof(void);
+extern long MRead(Tcl_Channel channel, char *data, long len);
+extern long MWrite(Tcl_Channel channel, char *data, long len);
 extern long VarToFix(unsigned char *var, int *len);
 extern int FixToVar(long fix, unsigned char *var);
 #endif
